==> cnblogs-theme-simplememory-2.2.5-2.2.5.tgz: package/docs/v2/README.md <==
<div align="center">

<img src="https://cdn.jsdelivr.net/gh/wangyang0210/pic/imgs/project/cnblogs/simple.webp" />

<br>

</div>

[![GitHub release](https://img.shields.io/github/v/release/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/releases)
[![GitHub stars](https://img.shields.io/github/stars/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/network)
[![GitHub issues](https://img.shields.io/github/issues/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/issues)
[![GitHub contributors](https://img.shields.io/github/contributors/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/graphs/contributors)
[![](https://data.jsdelivr.com/v1/package/gh/wangyang0210/cnblogs-theme/badge?style=rounded)](https://www.jsdelivr.com/package/gh/wangyang0210/cnblogs-theme)

[![GitHub last commit](https://img.shields.io/github/last-commit/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/commits/v2)
[![GitHub license](https://img.shields.io/badge/license-ISC-brightgreen)](https://github.com/wangyang0210/cnblogs-theme/blob/v2/LICENSE)
[![compatibility](https://camo.githubusercontent.com/31ac3f0ce805dc34a29b615131caa26cbf4dc127/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f62726f777365722d2532306368726f6d6525323025374325323066697265666f782532302537432532306f706572612532302537432532307361666172692532302537432532306965253230253345253344253230392d6c69676874677265792e737667)](https://github.com/wangyang0210/cnblogs-theme)


# Silence

📖 本主题以阅读为核心，美化博客园的显示效果，提高用户体验。

🍰 基于博皮“SimpleMemory”进行的修改；[页面效果](https://www.cnblogs.com/wangyang0210/)

🧀 支持响应，尺寸分别为：(1200px,∞px)，(960px,1200px]，(720px,960px]，(0px,720px]

# Docs

[永久地址](https://wangyang0210.github.io/cnblogs-theme/v2/#/)　[备用地址](https://docs.wangyangyang.vip/#/)

> 推荐大家使用最新版本，新版本的发布往往代表着功能的完善和bug的修复！
> <br>文档的源文件在 /docs 目录，大家有更完善的文档或建议可以 Pull Request 或 Issues 给我。
> <br>文档我已经禁止浏览器缓存，但仍可能存在缓存，大家可以尝试强制刷新下(ctrl+f5 / command+shift+r)

# Author

**Cnblogs-Theme** © [wangyang0210](https://github.com/wangyang0210), Released under the [MIT](./LICENSE) License.<br>

> Blog [@Blog](https://www.cnblogs.com/wangyang0210/) · GitHub [@GitHub](https://github.com/wangyang0210) · Email wangyang.0210@foxmail.com

==> cnblogs-theme-simplememory-2.2.14-2.2.14.tgz: package/docs/v2/README.md <==
<div align="center">

<img src="https://cdn.jsdelivr.net/gh/wangyang0210/pic/imgs/project/cnblogs/simple.webp" />

<br>

</div>

[![GitHub release](https://img.shields.io/github/v/release/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/releases)
[![GitHub stars](https://img.shields.io/github/stars/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/network)
[![GitHub issues](https://img.shields.io/github/issues/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/issues)
[![GitHub contributors](https://img.shields.io/github/contributors/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/graphs/contributors)
[![](https://data.jsdelivr.com/v1/package/gh/wangyang0210/cnblogs-theme/badge?style=rounded)](https://www.jsdelivr.com/package/gh/wangyang0210/cnblogs-theme)

[![GitHub last commit](https://img.shields.io/github/last-commit/wangyang0210/cnblogs-theme.svg)](https://github.com/wangyang0210/cnblogs-theme/commits/v2)
[![GitHub license](https://img.shields.io/badge/license-ISC-brightgreen)](https://github.com/wangyang0210/cnblogs-theme/blob/v2/LICENSE)
[![compatibility](https://camo.githubusercontent.com/31ac3f0ce805dc34a29b615131caa26cbf4dc127/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f62726f777365722d2532306368726f6d6525323025374325323066697265666f782532302537432532306f706572612532302537432532307361666172692532302537432532306965253230253345253344253230392d6c69676874677265792e737667)](https://github.com/wangyang0210/cnblogs-theme)


# Silence

📖 本主题以阅读为核心，美化博客园的显示效果，提高用户体验。

🍰 基于博皮“SimpleMemory”进行的修改；[页面效果](https://www.cnblogs.com/wangyang0210/)

🧀 支持响应，尺寸分别为：(1200px,∞px)，(960px,1200px]，(720px,960px]，(0px,720px]

# Docs

[永久地址](https://wangyang0210.github.io/cnblogs-theme/v2/#/)

> 推荐大家使用最新版本，新版本的发布往往代表着功能的完善和bug的修复！
> <br>文档的源文件在 /docs 目录，大家有更完善的文档或建议可以 Pull Request 或 Issues 给我。
> <br>文档我已经禁止浏览器缓存，但仍可能存在缓存，大家可以尝试强制刷新下(ctrl+f5 / command+shift+r)

# Author

**Cnblogs-Theme** © [wangyang0210](https://github.com/wangyang0210), Released under the [MIT](./LICENSE) License.<br>

> Blog [@Blog](https://www.cnblogs.com/wangyang0210/) · GitHub [@GitHub](https://github.com/wangyang0210) · Email wangyang.0210@foxmail.com
